import string

from .api import hexadecimal, hsl, rgb, cmyk
from ..offline.str import stringColor


def autodetect(args: str) -> int:
    """
    Using AutoDetect:

    Alert It only works if you are connected to the internet
    >>>
    >>> import hexacolors
    >>> hexacolors.autodetect('Blue') #Identify string
    >>> hexacolors.autodetect('#fff000') #Identify Hexadecimal
    >>> hexacolors.autodetect('255,255,255') #Identify RGB
    >>> hexacolors.autodetect('423,522,4,244') #Identify CMYK
    >>> hexacolors.autodetect('255,75%,64%') #Identify HSL
    """

    if args[0] == '#':
        hexadecimal(args)
    elif args.count('%') > 0:
        hsl(args)
    elif args.count(',') == 2:
        rgb(args)
    elif args.count(',') == 3:
        cmyk(args)
    elif args[0] in list(string.digits):
        hexadecimal(args)
    elif args[0] in list(string.ascii_letters):
        try:
            stringColor(args)
        except:
            hexadecimal(args)
    else:
        print('ERROR: Not indentify the type')



def slateblue():return 0x6A5ACD
def slateblue1():return 0x836FFF
def slateblue3():return 0x6959CD
def darkslateblue():return 0x483D8B
def midnightblue():return 0x191970
def navy():return 0x000080
def darkblue():return 0x00008B
def mediumblue():return 0x0000CD
def blue():return 0x0000FF
def cornflowerblue():return 0x6495ED
def royalblue():return 0x4169E1
def dodgerblue():return 0x1E90FF
def deepskyblue():return 0x00BFFF
def lightskyblue():return 0x87CEFA
def skyblue():return 0x87CEEB
def lightblue():return 0xADD8E6
def steelblue():return 0x4682B4
def lightsteelblue():return 0xB0C4DE
def slategray():return 0x708090
def lightslategray():return 0x778899


from ..colors.gray import *
from ..colors.blue import *
from ..colors.cyan import *
from ..colors.brown import *
from ..colors.purple import *
from ..colors.pink import *
from ..colors.green import *
from ..colors.red import *
from ..colors.orange import *
from ..colors.yellow import *
from ..colors.ligthcolors import *


def stringColor(cor: str) -> int:
    """
    Using StringColor:

    >>> import hexacolors
    >>> hexacolors.stringColor('Blue')
    >>> print(hexacolors.listall) #List all colors availables
    """

    match cor.lower().replace(' ', ''):

        case 'black': return black()
        case 'gray1': return grey11()
        case 'gray2': return grey21()
        case 'gray3': return grey31()
        case 'dimgray': return dimgray()
        case 'gray': return gray()
        case 'darkgray': return darkgray()
        case 'silver': return silver()
        case 'ligthgrey': return ligthgrey()
        case 'gainsboro': return gainsboro()
        case 'slateblue': return slateblue()
        case 'slateblue1': return slateblue1()
        case 'slateblue2': return slateblue3()
        case 'darkslateblue': return darkslateblue()
        case 'midnightblue': return midnightblue()
        case 'navy': return navy()
        case 'darkblue': return darkblue()
        case 'mediumblue': return mediumblue()
        case 'blue': return blue()
        case 'cornflowerblue': return cornflowerblue()
        case 'royalblue': return royalblue()
        case 'dodgerblue': return dodgerblue()
        case 'deepskyblue': return deepskyblue()
        case 'lightskyblue': return lightskyblue()
        case 'skyblue': return skyblue()
        case 'lightblue': return lightblue()
        case 'steelblue': return steelblue()
        case 'lightsteelblue': return lightsteelblue()
        case 'slategray': return slategray()
        case 'lightslategray': return lightslategray()
        case 'cyan': return cyan()
        case 'darkturquoise': return darkturquoise()
        case 'turquoise': return turquoise()
        case 'mediumturquoise': return mediumturquoise()
        case 'lightseagreen': return lightseagreen()
        case 'darkcyan': return darkcyan()
        case 'teal': return teal()
        case 'aquamarine': return aquamarine()
        case 'mediumaquamarine': return mediumaquamarine()
        case 'cadetblue': return cadetblue()
        case 'darkkhaki': return darkkhaki()
        case 'goldenrod': return goldenrod()
        case 'darkgoldenrod': return darkgoldenrod()
        case 'saddlebrown': return saddlebrown()
        case 'sienna': return sienna()
        case 'rosybrown': return rosybrown()
        case 'peru': return peru()
        case 'chocolate': return chocolate()
        case 'sandybrown': return sandybrown()
        case 'navajowhite': return navajowhite()
        case 'wheat': return wheat()
        case 'burlywood': return burlywood()
        case 'tan': return tan()
        case 'mediumslateBllue': return mediumslateBllue()
        case 'mediumpurple': return mediumpurple()
        case 'blueviolet': return blueviolet()
        case 'indigo': return indigo()
        case 'darkviolet': return darkviolet()
        case 'darkorchid': return darkorchid()
        case 'mediumorchid': return mediumorchid()
        case 'purple': return purple()
        case 'darkmagenta': return darkmagenta()
        case 'magenta': return magenta()
        case 'violet': return violet()
        case 'orchid': return orchid()
        case 'plum': return plum()
        case 'mediumvioletred': return mediumvioletred()
        case 'deeppink': return deeppink()
        case 'hotpink': return hotpink()
        case 'palevioletred': return palevioletred()
        case 'lightpink': return lightpink()
        case 'pink': return pink()
        case 'lightcoral': return lightcoral()
        case 'indianred': return indianred()
        case 'crimson': return crimson()
        case 'darkslategreen': return darkslategreen()
        case 'mediumspringgreen': return mediumspringgreen()
        case 'springgreen': return springgreen()
        case 'palegreen': return palegreen()
        case 'lightgreen': return lightgreen()
        case 'darkseagreen': return darkseagreen()
        case 'mediumseagreen': return mediumseagreen()
        case 'seagreen': return seagreen()
        case 'darkgreen': return darkgreen()
        case 'green': return green()
        case 'forestgreen': return forestgreen()
        case 'limegreen': return limegreen()
        case 'lime': return lime()
        case 'lawngreen': return lawngreen()
        case 'chartreuse': return chartreuse()
        case 'greenyellow': return greenyellow()
        case 'yellowgreen': return yellowgreen()
        case 'olivedrab': return olivedrab()
        case 'darkolivegreen': return darkolivegreen()
        case 'olive': return olive()
        case 'maroon': return maroon()
        case 'darkred': return darkred()
        case 'firebrick': return firebrick()
        case 'brown': return brown()
        case 'salmon': return salmon()
        case 'darksalmon': return darksalmon()
        case 'lightsalmon': return lightsalmon()
        case 'coral': return coral()
        case 'tomato': return tomato()
        case 'red': return red()
        case 'orangered': return orangered()
        case 'darkorange': return darkorange()
        case 'orange': return orange()
        case 'gold': return gold()
        case 'yellow': return yellow()
        case 'khaki': return khaki()
        case 'white': return white()
        case 'aliceblue': return aliceblue()
        case 'ghostwhite': return ghostwhite()
        case 'snow': return snow()
        case 'seashell': return seashell()
        case 'floralwhite': return floralwhite()
        case 'whitesmoke': return whitesmoke()
        case 'beige': return beige()
        case 'oldlace': return oldlace()
        case 'ivory': return ivory()
        case 'linen': return linen()
        case 'cornsilk': return cornsilk()
        case 'antiquewhite': return antiquewhite()
        case 'blanchedalmond': return blanchedalmond()
        case 'bisque': return bisque()
        case 'lightyellow': return lightyellow()
        case 'lemonchiffon': return lemonchiffon()
        case 'lightgoldenrodyellow': return lightgoldenrodyellow()
        case 'papayawhip': return papayawhip()
        case 'peachpuff': return peachpuff()
        case 'moccasin': return moccasin()
        case 'palegoldenrod': return palegoldenrod()
        case 'mistyrose': return mistyrose()
        case 'lavenderblush': return lavenderblush()
        case 'lavender': return lavender()
        case 'thistle': return thistle()
        case 'azure': return azure()
        case 'lightcyan': return lightcyan()
        case 'powderblue': return powderblue()
        case 'paleturquoise': return paleturquoise()
        case 'honeydew': return honeydew()
        case 'mintcream': return mintcream()



def hexadecimaloff(hexa: str) -> int:

    """
    Using HexaColor:

    >>> import hexacolors
    >>> hexacolors.hexadecimaloff('#0000FF') #Convert Hexadecimal Color for Python understand
    """

    if hexa[0] == '#':
        hexa = hexa[1::]

    return int(f"0x{hexa}", 16)

def rgboff(r: int, g: int, b: int) -> int:

    """
    Using rgb:

    >>> import hexacolors
    >>> hexacolors.rgboff(255,255,255)
    """

    return int('0x{:X}{:X}{:X}'.format(r, g, b), 16)

def cmykoff(c: int, m: int, y: int, k: int) -> int:

    """
    Using cmyk:

    >>> import hexacolors
    >>> hexacolors.cmykoff('423,522,4,244')
    """

    return int('0x{:X}{:X}{:X}{:X}'.format(c, m, y, k), 16)



def darkslategreen():return 0x2F4F4F
def mediumspringgreen():return 0x00FA9A
def springgreen():return 0x00FF7F
def palegreen():return 0x98FB98
def lightgreen():return 0x90EE90
def darkseagreen():return 0x8FBC8F
def mediumseagreen():return 0x3CB371
def seagreen():return 0x2E8B57
def darkgreen():return 0x006400
def green():return 0x008000
def forestgreen():return 0x228B22
def limegreen():return 0x32CD32
def lime():return 0x00FF00
def lawngreen():return 0x7CFC00
def chartreuse():return 0x7FFF00
def greenyellow():return 0xADFF2F
def yellowgreen():return 0x9ACD32
def olivedrab():return 0x6B8E23
def darkolivegreen():return 0x556B2F
def olive():return 0x808000


import requests

def hexadecimal(hexa: str) -> int:

    """
    Using HexaColor:

    >>> import hexacolors
    >>> hexacolors.hexadecimal('#0000FF') #Convert Hexadecimal Color for Python understand
    """

    if hexa[0] == '#':
        hexa = hexa[1::]
    
    p = requests.get(f'https://www.thecolorapi.com/id?hex={hexa}')

    return int(f"0x{p.json()['hex']['clean']}",  16)


def rgb(rgb: str) -> int:

    """
    Using rgb:

    >>> import hexacolors
    >>> hexacolors.rgb('255,255,255')
    """
    
    p = requests.get(f'https://www.thecolorapi.com/id?rgb={rgb}')
    
    return int(f"0x{p.json()['hex']['clean']}", 16)

def cmyk(cmyk: str) -> int:

    """
    Using cmyk:

    >>> import hexacolors
    >>> hexacolors.cmyk('423,522,4,244')
    """

    p = requests.get(f'https://www.thecolorapi.com/id?cmyk={cmyk}')

    return int(f"0x{p.json()['hex']['clean']}", 16)

def hsl(hsl: str) -> int:

    """
    Using hsl:

    >>> import hexacolors
    >>> hexacolors.hsl('423,60%,70%')
    """

    p = requests.get(f'https://www.thecolorapi.com/id?hsl={hsl}')

    return int(f"0x{p.json()['hex']['clean']}", 16)



def maroon():return 0x800000
def darkred():return 0x8B0000
def firebrick():return 0xB22222
def brown():return 0xA52A2A
def salmon():return 0xFA8072
def darksalmon():return 0xE9967A
def lightsalmon():return 0xFFA07A
def coral():return 0xFF7F50
def tomato():return 0xFF6347
def red():return 0xFF0000


def mediumslateBllue():return 0x7B68EE
def mediumpurple():return 0x9370DB
def blueviolet():return 0x8A2BE2
def indigo():return 0x4B0082
def darkviolet():return 0x9400D3
def darkorchid():return 0x9932CC
def mediumorchid():return 0xBA55D3
def purple():return 0xA020F0
def darkmagenta():return 0x8B008B
def magenta():return 0xFF00FF
def violet():return 0xEE82EE
def orchid():return 0xDA70D6
def plum():return 0xDDA0DD


def darkkhaki():return 0xBDB76B
def goldenrod():return 0xDAA520
def darkgoldenrod():return 0xB8860B
def saddlebrown():return 0x8B4513
def sienna():return 0xA0522D
def rosybrown():return 0xBC8F8F
def peru():return 0xCD853F
def chocolate():return 0xD2691E
def sandybrown():return 0xF4A460
def navajowhite():return 0xFFDEAD
def wheat():return 0xF5DEB3
def burlywood():return 0xDEB887
def tan():return 0xD2B48C


from setuptools import setup

with open("README.md", "r") as f:

    long_description = f.read()

setup(
    name="hexacolors",
    version="0.5.3",
    url = 'https://github.com/Marciel404/hexacolors',
    author="Marciel404",
    description='''
:A simple library that converts string to hexadecimal understandable by python
:A simple library that converts RGB to hexadecimal understandable by python
:A simple library that converts CMYK to hexadecimal understandable by python
:A simple library that converts HSL to hexadecimal understandable by python
:A simple library that converts hexadecimal understandable by python
''',
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=["hexacolors", "hexacolors.colors", "hexacolors.offline", "hexacolors.online"],
    license = 'MIT',
    keywords = 'String hexadecimal converter' ,
    CLASSIFIERS = [
    'Intended Audience :: Developers',
    'Topic :: colors',
    'License :: MIT License',
    'Programming Language :: Python',
    ],
    python_requires='>=3.10',
    install_requires=['requests>=2.28.1'],
    dependency_links=['https://github.com/Marciel404/hexacolors']
)


def mediumvioletred():return 0xC71585
def deeppink():return 0xFF1493
def hotpink():return 0xFF69B4
def palevioletred():return 0xDB7093
def lightpink():return 0xFFB6C1
def pink():return 0xFFC0CB
def lightcoral():return 0xF08080
def indianred():return 0xCD5C5C
def crimson():return 0xDC143C


"""
Hexacolors
~~~~~~~~~~

:A simple library that converts string to hexadecimal understandable by python
:A simple library that converts RGB to hexadecimal understandable by python
:A simple library that converts CMYK to hexadecimal understandable by python
:A simple library that converts CMYK to hexadecimal understandable by python
:A simple library that converts hexadecimal understandable by python

:(c) 2022-present Marciel404
:license: MIT, see LICENSE for more details.
:I created this library to use as with the pycord integration so I don't know if it works elsewhere
"""

__title__ = "Hexacolors"
__author__ = "Marciel404"
__license__ = "MIT"
__copyright__ = "2022-present Marciel404"
__version__ = "0.5.3"

from .offline.str import stringColor
from .offline.converoff import hexadecimaloff, rgboff, cmykoff
from .online.autodetect import autodetect
from .online.api import hexadecimal, rgb, cmyk, hsl

from .colors._listcolors_ import (
    listblack,
    listblue,
    listcyan,
    listgreen,
    listbrown,
    listpurple,
    listpink,
    listred,
    listorange,
    listyellow,
    listlight,
    listall
)


def white():return 0xFFFFFF
def aliceblue():return 0xF0F8FF
def ghostwhite():return 0xF8F8FF
def snow():return 0xFFFAFA
def seashell():return 0xFFF5EE
def floralwhite():return 0xFFFAF0
def whitesmoke():return 0xF5F5F5
def beige():return 0xF5F5DC
def oldlace():return 0xFDF5E6
def ivory():return 0xFFFFF0
def linen():return 0xFAF0E6
def cornsilk():return 0xFFF8DC
def antiquewhite():return 0xFAEBD7
def blanchedalmond():return 0xFFEBCD
def bisque():return 0xFFE4C4
def lightyellow():return 0xFFFFE0
def lemonchiffon():return 0xFFFACD
def lightgoldenrodyellow():return 0xFAFAD2
def papayawhip():return 0xFFEFD5
def peachpuff():return 0xFFDAB9
def moccasin():return 0xFFE4B5
def palegoldenrod():return 0xEEE8AA
def mistyrose():return 0xFFE4E1
def lavenderblush():return 0xFFF0F5
def lavender():return 0xE6E6FA
def thistle():return 0xD8BFD8
def azure():return 0xF0FFFF
def lightcyan():return 0xE0FFFF
def powderblue():return 0xB0E0E6
def paleturquoise():return 0xE0FFFF
def honeydew():return 0xF0FFF0
def mintcream():return 0xF5FFFA